/**
 * Helpful tools for formatting strings and tracing output.
 * All functions are static so this does not need to be instantiated.
 */
class StockUtils {
	
	/**
	 * Gets a friendly time-only string
	 */
	public static function formatDate(d:Date) {
		// format date as 10-Mar-2003
		var months = ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"];
		return d.getDate()+"-"+months[d.getMonth()]+"-"+d.getFullYear();
	}
	
	/**
	 * Gets a friendly time-only string
	 */
	public static function formatTime(d:Date) {
		
		// format time as 11:58 AM
		var hours = d.getHours();
		var minutes = d.getMinutes();
		
		// leading zero in front of single digit minutes
		if (minutes<10) {
			minutes = "0"+minutes;
		}
		var timeStr;
		if (hours>11) {
			timeStr = (hours == 12 ? hours : hours-12)+":"+minutes+" PM";
		} else {
			timeStr = hours+":"+minutes+" AM";
		}
		return timeStr;
	}
	
	/**
	 * Turns a number like 20434 into 20,434
	 */ 
	public static function addCommas(inNum) {
		var outStr = String(Math.round(Math.abs(inNum)));
		
		// step back every three characters, insert comma
		for (var i = outStr.length-3; i>0; i=i-3) {
			outStr = outStr.substr(0, i)+","+outStr.substr(i);
		}
		return outStr;
	}
	
	/**
	 * Allows or prevents trace output
	 */
	public static var bIsTracingEnabled:Boolean = true;
	
	/**
	 * Sends formatted debug output to the trace area. 
	 * If you want to disable all tracing set bIsTracingEnabled to false.
	 */
	public static function trace(msg:String, src:String) {
		if (bIsTracingEnabled) {
			// Output a prefix so it's easier to follow in the Central Debug Player output file
			// (where trace output from all Central apps is interspersed)
			var msgPrefix = "=== SW === ";
			if (src != undefined) {
				// identify which module within the app sent this output
				msgPrefix += "[" + src + "] ";
			}
			trace(msgPrefix + msg);
		}
	}
		
	/**
	 * Outputs the value of every property in an object
	 */
	public static function traceProps(msg:String, obj:Object):Void {
		if (bIsTracingEnabled) {
			StockUtils.trace(msg);
			if (obj != undefined) {
	
				// send each property name and value to the destination
				for (var prop in obj) {
					StockUtils.trace("  ." + prop + "=" + obj[prop]);
				}
			} else {
				StockUtils.trace(" = undefined");
			}
		}
	}
}
